C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE creadi(cstr,ival,ierr)

C @(#)Subroutine: creadi             Author: R.A. Jansen -- Oct 24, 2000
C @(#)
C @(#)  Purpose: Read an integer value  'ival'  from  a character string
C @(#)    'cstr'.
C @(#)
C @(#)  Calling sequence: CALL creadi(cstr,ival,ierr)  , where 'cstr' is
C @(#)    a character string of arbitrary declared length, and 'ival' is
C @(#)    an integer.  Error flag 'ierr'  will be returned non-zero upon
C @(#)    exit if an error condition was triggered (in which case 'ival'
C @(#)    retains its input value or remains undefined).
C @(#)
C @(#)  Note: if the largest integer to be read has more than 32 digits,
C @(#)    the declared length of variable 'ctmp' should be increased.
C @(#)
C @(#)  Dependencies:     cinit, clen
C @(#)
C @(#)  Revision history:
C @(#)    Jun 10, 2008 [RAJ] -- expanded documentation;  added check  to
C @(#)                          see whether input string fits in 'ctmp'.
C @(#)    Aug  2, 2008 [RAJ] -- added  descriptive message  for internal
C @(#)                          error conditions.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER*(*) cstr
      INTEGER	ival, ierr

C --- Declaration of local variables...
      CHARACTER	ctmp*32
      INTEGER	itmp, clen

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C --- Initialize...
      CALL cinit(ctmp)

C --- Try and read an integer from the given character string...
      IF (clen(cstr).EQ.0.OR.clen(cstr).GT.(LEN(ctmp)-2)) THEN
         ierr = 1
         IF (clen(cstr).EQ.0) THEN
            CALL error('creadi','input cstr appears to be blank')
         ELSE
            CALL error('creadi','input cstr would overflow buffer ctmp')
         ENDIF
      ELSE
         ctmp(2:(clen(cstr)+1)) = cstr(1:clen(cstr))
         READ(ctmp,*,IOSTAT=ierr) itmp
      ENDIF
      IF (ierr.NE.0) RETURN

C --- Return the integer value read from 'cstr'...
      ival = itmp

      RETURN
      END


C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE creadr(cstr,rval,ierr)

C @(#)Subroutine: creadr             Author: R.A. Jansen -- Oct 24, 2000
C @(#)
C @(#)  Purpose: Read  a floating point  value 'rval'  from a  character
C @(#)    string 'cstr'.
C @(#)
C @(#)  Calling sequence: CALL creadr(cstr,rval,ierr)  , where 'cstr' is
C @(#)    a character string of arbitrary declared length, and 'rval' is
C @(#)    a floating point (real) value.  Error flag 'ierr' will be non-
C @(#)    zero upon exit  if an error condition was triggered  (in which
C @(#)    case 'rval' retains its input value or remains undefined).
C @(#)
C @(#)  Note: if the largest floating point value to be read  exceeds 32
C @(#)    digits (including the decimal point), then the declared length
C @(#)    of variable 'ctmp' should be increased.
C @(#)
C @(#)  Dependencies:     cinit, clen
C @(#)
C @(#)  Revision history:
C @(#)    Jun 10, 2008 [RAJ] -- expanded documentation;  added check  to
C @(#)                          see whether input string fits in 'ctmp'.
C @(#)    Aug  2, 2008 [RAJ] -- added  descriptive message  for internal
C @(#)                          error conditions.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER*(*) cstr
      REAL	rval
      INTEGER	ierr

C --- Declaration of local variables...
      CHARACTER	ctmp*32
      REAL	rtmp
      INTEGER	clen

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C --- Initialize... 
      CALL cinit(ctmp)

C --- Try and read a floating point value from given character string...
      IF (clen(cstr).EQ.0.OR.clen(cstr).GT.(LEN(ctmp)-2)) THEN
         ierr = 1
         IF (clen(cstr).EQ.0) THEN
            CALL error('creadr','input cstr appears to be blank')
         ELSE
            CALL error('creadr','input cstr would overflow buffer ctmp')
         ENDIF
      ELSE
         ctmp(2:(clen(cstr)+1)) = cstr(1:clen(cstr))
         READ(ctmp,*,IOSTAT=ierr) rtmp
      ENDIF
      IF (ierr.NE.0) RETURN

C --- Return the floating point value read from 'cstr'...
      rval = rtmp

      RETURN
      END
