C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE freadc(iunit,cstr,ierr)

C @(#)Subroutine: freadc             Author: R.A. Jansen -- Aug 26, 1998
C @(#)
C @(#)  Purpose: Read a character string 'cstr'  from a specified device
C @(#)    unit 'iunit'.
C @(#)
C @(#)  Calling sequence: CALL freadc(iunit,cstr,ierr)  , where  'iunit'
C @(#)    must be open for reading already,  and  'cstr'  is a character
C @(#)    string of arbitrary declared length.
C @(#)
C @(#)  Dependencies:     cinit, clen
C @(#)
C @(#)  Note: if the longest character string to be read may exceed 1024
C @(#)    characters, the declared length of variable  'ctmp'  should be
C @(#)    increased.
C @(#)
C @(#)  Revision history:
C @(#)    May 22, 2008 [RAJ] -- expanded documentation.
C @(#)    Jul 31, 2008 [RAJ] -- explicit initialization of 'cstr'; fixed
C @(#)                          potential bug that allowed writing  more
C @(#)                          characters than might fit in 'cstr'.
C @(#)------------------------------------------------------------------

      CHARACTER*(*) cstr, ctmp*1024
      INTEGER	iunit, ierr, mlen, clen

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C --- Initialize output string with blanks...
      CALL cinit(cstr)

C --- Try and read a character string from the input device...
      READ(iunit,'(A)',IOSTAT=ierr) ctmp
      IF (ierr.NE.0) RETURN

C --- Minimum of characters read and declared length of output 'cstr'...
      mlen = MIN(clen(ctmp),LEN(cstr))

C --- Copy (possibly truncate) into 'cstr' up to the last non-blank
C     character of the string just read...
      IF (clen(ctmp).GT.0) cstr(1:mlen) = ctmp(1:mlen)

      RETURN
      END


