C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            
      SUBROUTINE gutc(year,month,day,hours,minutes,seconds,ierr)
            
C @(#)Subroutine: gutc               Author: R.A. Jansen -- Jun 10, 2008
C @(#)
C @(#)  Purpose: Return the approximate  Universal Time corresponding to
C @(#)    the input local date and time. This routine applies the formal
C @(#)    offset in (integer) hours between local time and UT,  as given
C @(#)    at compile time through  'tmzone.inc',  to the specified local
C @(#)    time.  It does not return an astronomically exact UTC  (we use
C @(#)    the host computer's sense of what the local time might be).
C @(#)
C @(#)  Calling sequence: CALL gutc(CCYY,MM,DD,hh,mm,ss) , where each of
C @(#)    the input parameters (year,month,day,hours,minutes,seconds) is
C @(#)    an integer.
C @(#)
C @(#)  Dependencies:     error; 'tmzone.inc'
C @(#)
C @(#)  Revision history:
C @(#)    Jun 10, 2008 [RAJ] -- new routine; split off from 'gdate'.
C @(#)------------------------------------------------------------------

C --- Learn about local time zone...
      INCLUDE   'tmzone.inc'
         
C --- Declaration of input variables...
      INTEGER   year, month, day, hours, minutes, seconds, ierr
         
C --- Declaration of local variables...
      INTEGER   iyear, imon, iday, ihrs, imin, isec
      INTEGER   uyear, umon, uday, uhrs, umin, usec

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C --- Initialize...
      iyear = year
      imon  = month
      iday  = day
      ihrs  = hours
      imin  = minutes
      isec  = seconds

      IF (imon.LT.1.OR.imon.GT.12) ierr = 1
      IF (iday.LT.1.OR.iday.GT.31) ierr = 1
      IF (ihrs.LT.0.OR.ihrs.GT.24) ierr = 1
      IF (imin.LT.0.OR.imin.GT.60) ierr = 1
      IF (isec.LT.0.OR.isec.GT.60) ierr = 1
      IF (ierr.NE.0) THEN
         CALL error('GUTC','component of local date/time out of range!')
         RETURN
      ENDIF
      
C --- Determine (approximate) UTC from the local time, corrected for any
C     daylight savings time offset (if the DLS flag value appears valid;
C     silently ignore otherwise)...
      uyear = iyear
      umon  = imon
      uday  = iday
      uhrs  = ihrs - UTH
      umin  = imin
      usec  = isec
      IF (DLS.EQ.0.OR.DLS.EQ.1) uhrs = uhrs - DLS
         
C --- Test wether the offset to UT caused us to cross a day, month or
C     year boundary...
      IF (uhrs.GT.24) THEN
         uhrs = uhrs - 24
         uday = iday + 1
         IF (uday.GT.31.AND.(imon.EQ.1.OR.imon.EQ.3.OR.imon.EQ.5
     +                      .OR.imon.EQ.7.OR.imon.EQ.8
     +                      .OR.imon.EQ.10.OR.imon.EQ.12)        ) THEN
            umon = imon + 1
            uday = 1
         ENDIF
         IF (uday.GT.30.AND.(imon.EQ.4.OR.imon.EQ.6
     +                       .OR.imon.EQ.9.OR.imon.EQ.11) ) THEN
            umon = imon + 1
            uday = 1
         ENDIF 
         IF (uday.GT.29.AND.imon.EQ.2) THEN
            umon = imon + 1
            uday = 1
         ENDIF
         IF (uday.GT.28.AND.imon.EQ.2) THEN
            IF (MOD(uyear,400).EQ.0) THEN
               umon = 2
               uday = 29
            ELSE IF (MOD(uyear,100).EQ.0) THEN
               umon = 3
               uday = 1
            ELSE IF (MOD(uyear,4).EQ.0) THEN
               umon = 2
               uday = 29
            ELSE
               umon = 3
               uday = 1
            ENDIF
         ENDIF
      ENDIF

      IF (uhrs.LT.0) THEN
         uhrs = uhrs + 24
         uday = iday - 1
         IF (uday.LT.1.AND.(imon.EQ.1.OR.imon.EQ.2.OR.imon.EQ.4
     +                      .OR.imon.EQ.6.OR.imon.EQ.8
     +                      .OR.imon.EQ.9.OR.imon.EQ.11)        ) THEN
            umon = imon - 1
            uday = 31
         ENDIF
         IF (uday.LT.1.AND.(imon.EQ.5.OR.imon.EQ.7
     +                      .OR.imon.EQ.10.OR.imon.EQ.12) ) THEN
            umon = imon - 1
            uday = 30
         ENDIF
         IF (uday.LT.1.AND.imon.EQ.3) THEN
            umon = imon - 1
            IF (MOD(uyear,400).EQ.0) THEN
               uday = 29
            ELSE IF (MOD(uyear,100).EQ.0) THEN
               uday = 28
            ELSE IF (MOD(uyear,4).EQ.0) THEN
               uday = 29
            ELSE
               uday = 28
            ENDIF
         ENDIF    
      ENDIF
            
      IF (umon.GT.12) THEN
         umon = 1
         uyear = iyear + 1
      ENDIF   

      IF (umon.LT.1) THEN
         umon = 12
         uyear = iyear - 1
      ENDIF

C --- Return the components of the Universal date/time...
      year    = uyear
      month   = umon
      day     = uday 
      hours   = uhrs
      minutes = umin
      seconds = usec
            
      RETURN
      END


