C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE opendev(iunit,cdev,cstat,cmode,recl,ierr)

C @(#)Subroutine: opendev            Author: R.A. Jansen -- Aug  2, 2008
C @(#)
C @(#)  Purpose: Open named device 'cdev' at logical device unit 'iunit'
C @(#)    for read- or write-access and for direct or sequential access.
C @(#)
C @(#)  Calling sequence: CALL opendev(iunit,cdev,cstat,cmod,recl,ierr),
C @(#)    where  'cdev'  can be a character string of arbitrary declared
C @(#)    length representing a disk file name,  'iunit'  can be a manu-
C @(#)    ally specified  logical device unit  or a standard device, and
C @(#)    'cstat'  a character string of arbitrary declared length, with
C @(#)    a value of  'r[ead]', 'w[rite]', 'OLD', 'NEW',  or  'UNKNOWN'.
C @(#)    The type of access is further specified by 'cmode',  which can
C @(#)    have a value  of either 'SEQUENTIAL'/'NO'  or  'DIRECT'/'YES'.
C @(#)    Both  'cstat'  and  'cmode'  are case insensitive.  The record
C @(#)    length parameter  'recl'  only takes effect  in  DIRECT access
C @(#)    mode and is ignored otherwise.  Upon exit,  error flag  'ierr'
C @(#)    will be returned non-zero if an error condition was triggered.
C @(#)
C @(#)  Dependencies:     ucase, clen, error; 'devices.inc'
C @(#)
C @(#)  Revision history:
C @(#)    Aug 26, 1998 [RAJ] -- Original version (from 'mysurfphot').
C @(#)    Oct 30, 2000 [RAJ] -- added checks and translations for "read"
C @(#)                          and "write" access  (and abbreviations),
C @(#)                          and for existence/non-existence of file.
C @(#)    May 20, 2008 [RAJ] -- expanded documentation.
C @(#)    Jul 30, 2008 [RAJ] -- changed SEQUENTIAL to DIRECT + FORMATTED 
C @(#)                          access to fix a bug in code, that worked
C @(#)                          on most FITS images but failed on others
C @(#)                          (possibly OS dependent!)
C @(#)    Aug  2, 2008 [RAJ] -- made file access in SEQUENTIAL or DIRECT
C @(#)                          ACCESS mode and the record length in the
C @(#)                          latter case  an input parameter,  making
C @(#)                          the routine far more general.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Learn about default devices...
      INCLUDE	'devices.inc'

C --- Declaration of input/return variables...
      CHARACTER*(*) cdev, cstat, cmode
      INTEGER	iunit, recl, ierr

C --- Declaration of local variables...
      CHARACTER	acmode(2)*10, cstr*80, form*8
      INTEGER	clen
      LOGICAL	exist

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN
C     Return for illegal or standard I/O unit numbers...
      IF (iunit.LE.0.OR.iunit.EQ.STDOUT.OR.iunit.EQ.STDIN) RETURN

C --- Translate possible aliases for 'cstat' and 'cmode'...
      CALL ucase(cstat,acmode(1))
      IF (acmode(1)(1:clen(acmode(1))).EQ.'R'
     +    .OR.acmode(1)(1:clen(acmode(1))).EQ.'READ') THEN
         acmode(1) = 'OLD       '
      ELSE IF (acmode(1)(1:clen(acmode(1))).EQ.'W'
     +         .OR.acmode(1)(1:clen(acmode(1))).EQ.'WRITE') THEN
         acmode(1) = 'UNKNOWN   '
      ELSE IF (acmode(1)(1:clen(acmode(1))).EQ.'OLD') THEN
         acmode(1) = 'OLD       '
      ELSE IF (acmode(1)(1:clen(acmode(1))).EQ.'NEW') THEN
         acmode(1) = 'NEW       '
      ELSE
         acmode(1) = 'UNKNOWN   '
      ENDIF

      CALL ucase(cmode,acmode(2))
      IF (    acmode(2)(1:clen(acmode(2))).EQ.'DIRECT'
     +    .OR.acmode(2)(1:clen(acmode(2))).EQ.'YES'   ) THEN
         acmode(2) = 'DIRECT    '
      ELSE
         acmode(2) = 'SEQUENTIAL'
      ENDIF

C --- Test the existence of the named device...
      INQUIRE(FILE=cdev(1:clen(cdev)),EXIST=exist,FORMATTED=form)
      IF (acmode(1)(1:clen(acmode(1))).EQ.'NEW'.AND.exist) THEN
         cstr = 'file "'//cdev(1:clen(cdev))//'" already exists!'
         GOTO 1
      ENDIF
      IF (acmode(1)(1:clen(acmode(1))).EQ.'OLD'.AND..NOT.exist) THEN
         cstr = 'file "'//cdev(1:clen(cdev))//'" not found!'
         GOTO 1
      ENDIF

C --- Try and open the named device for reading...
      cstr = 'opening file "'//cdev(1:clen(cdev))//'"'
      IF (form(1:clen(form)).EQ.'YES') THEN
         cstr = cstr(1:clen(cstr))//' for formatted '//
     +          acmode(2)(1:clen(acmode(2)))//' access!'
         OPEN(UNIT=iunit, FILE=cdev(1:clen(cdev)), STATUS=acmode(1),
     +        ACCESS=acmode(2), FORM='FORMATTED', RECL=recl,
     +        BLANK='NULL', ERR=1)
      ELSE
         cstr = cstr(1:clen(cstr))//' for unformatted '//
     +          acmode(2)(1:clen(acmode(2)))//' access!'
         OPEN(UNIT=iunit, FILE=cdev(1:clen(cdev)), STATUS=acmode(1),
     +        ACCESS=acmode(2), FORM='UNFORMATTED', RECL=recl,
     +        BLANK='NULL', ERR=1)
      ENDIF
      RETURN

1     ierr = 1
      CALL error('opendev',cstr)

      RETURN
      END


