C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE parse(cstr,delim,cpar,lpar)

C @(#)Subroutine: parse               Author: R.A. Jansen -- Apr 29 1997
C @(#)
C @(#)  Purpose: parse character string 'cstr' into fields, interpreting
C @(#)    SPACE,  COMMA  and TAB  as field-separating characters, unless
C @(#)    'delim' is specified (ie other than ""), in which case 'delim'
C @(#)    is used as a field separator exclusively.  The returned string
C @(#)    'cstr' equals the remainder of the input string,  exclusive of
C @(#)    the  first field.  Character string  'cpar'  will contain that
C @(#)    first field and  'lpar'  will return the actual (as opposed to
C @(#)    declared) length of  'cpar' (ignoring any trailing blanks). If
C @(#)    'delim' does not occur within the input character string, upon
C @(#)    exit  'cstr' will be empty  and  'cpar' will contain the input
C @(#)    string (or a truncated copy,  if its length is insufficient to
C @(#)    hold  the entire  string).  This routine derives in part  from
C @(#)    earlier code by M. Franx.
C @(#)
C @(#)  Calling sequence: CALL parse(cstr,delim,cpar,lpar), where 'cstr'
C @(#)    and 'cpar' are character strings of arbitrary declared length,
C @(#)    'delim'  is a single character or empty string,  and 'lpar' an
C @(#)    integer. This routine has neither input nor exit error status.
C @(#)
C @(#)  Dependencies:     clen
C @(#)
C @(#)  Revision history:
C @(#)    Aug  3, 2008 [RAJ] -- expanded documentation.
C @(#)    Aug  5, 2008 [RAJ] -- fixed the case where the declared length
C @(#)                          of  'cpar'  is insufficient  to hold the
C @(#)                          entire field.
C @(#)    Jun 29, 2010 [RAJ] -- fixed bug of unitialized 'lpar' introdu-
C @(#)                          ced in the Aug 5 2008 bug fix.
C @(#)------------------------------------------------------------------
      
      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER*(*) cstr, cpar, delim*1
      INTEGER	lpar

C --- Declaration of local variables...
      CHARACTER	space*1, comma*1, tab*1
      INTEGER	clen, l1, l2, j, mlen
      LOGICAL	white, lastwhite
      DATA	space/' '/,comma /','/

C --- Initialize...
      lastwhite = .TRUE.
      tab = char(9)
      l1  = 0
      l2  = clen(cstr)
      mlen = MIN(l2,LEN(cpar))

C --- Find the first instance of the field-delimiter in 'cstr' after the
C     first instance of any other character (i.e., ignore leading delim-
C     iting characters in the string such as leading spaces or tabs)...
      DO j=1,clen(cstr)
         IF (delim.NE.CHAR(32)) THEN
            white = (cstr(j:j).EQ.delim)
         ELSE
            white = (    cstr(j:j).EQ.space
     +               .OR.cstr(j:j).EQ.comma
     +               .OR.cstr(j:j).EQ.tab  )
         ENDIF
         IF (.NOT.white.AND.lastwhite) THEN
C           Found the first non-delimiting character in the string...
            l1 = j
         ELSE IF (white.AND..NOT.lastwhite) THEN
C           Found the first non-leading instance of the delimiter...
            l2 = j - 1
            GOTO 1
         ENDIF
         lastwhite = white
      ENDDO

C --- Return the 1st field and remainder of the input string...
1     IF (l1.GT.0) THEN
C        First field...
         lpar = l2 - l1 + 1
         IF (lpar.LE.mlen) THEN
            cpar = cstr(l1:l2)
         ELSE
            lpar = mlen
            cpar = cstr(l1:(l1+lpar-1))
         ENDIF
C        computer actual length of field (ignore trailing blanks)...
         lpar = clen(cpar)

C        Remainder of input string...
         l1   = l2 + 2
         IF (l1.LE.clen(cstr)) THEN
            cstr = cstr(l1:)
         ELSE
            cstr = CHAR(32)
         ENDIF
      ELSE
C        The delimiting character does not occur in the input string...
         lpar = 0
         cpar = CHAR(32)
      ENDIF

      RETURN
      END


