C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE rjfgkcom (crec, comm, ityp, idbg, ierr)

C @(#)Subroutine: rjfgkcom           Author: R.A. Jansen -- Oct 14, 2009
C @(#)
C @(#)  Purpose: Read a keyword comment 'comm' from a FITS header record
C @(#)    'crec'  containing a keyword value of type 'ityp' (as returned
C @(#)    by 'rjfvkval'). If not keyword comment is present, 'comm' will
C @(#)    be blank upon exit.   If verbosity level 'idbg'>0,  additional
C @(#)    messages may be printed.  Should any error condition be detec-
C @(#)    ted, error status 'ierr' will be non-zero upon exit. Its value
C @(#)    (if >2000) uniquely identifies a known error condition.
C @(#)
C @(#)  Calling sequence:  CALL rjfgkcom (crec, comm, ityp, idbg, ierr),
C @(#)    where 'crec' and 'comm' are char strings with declared lengths
C @(#)    of 80 characters; 'ityp','idbg' and 'ierr' are all integers.
C @(#)
C @(#)  Note:  this task is normally run after 'rjfvkval' and one of the
C @(#)    'rjfgkval*' family of routines.
C @(#)
C @(#)  Dependencies:	clen, cinit, cidx, lenc
C @(#)
C @(#)  Revision history:
C @(#)    Oct 14, 2009 [RAJ] -- Initial version of this routine.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER	crec*80, comm*80
      INTEGER	idbg, ierr
      LOGICAL	ltrnc

C --- Declaration of local variables...
      CHARACTER dbid*19, ctmp*80, cc
      INTEGER	clen, i, j, k

C     ------------------------------------------------------------------

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C --- Initialize the debugging ID string...
      dbid  = 'DEBUG(rjfpkcom): '

C --- Initialize local variable...
      CALL cinit(ctmp)

C --- Test whether the keyword comment already starts with a '/' ...
      cc = comm(1:1)
      IF (cc.EQ.'/') THEN
C        Keyword comment string already includes the comment indicator..
         cc = comm(2:2)
         IF (cc.NE.' ') THEN
C           Add the recommended space between the '/' and the comment...
            IF (idbg.GT.1) WRITE(*,*) dbid//
     +         ' adding recommended space between / and comment text'
            ctmp(1:2)  = '/ '
            ctmp(3:80) = comm(2:79)
            comm = ctmp
         ENDIF
      ELSE
C        Prepend a comment indicator plus space to the comment string...
         IF (idbg.GT.1) WRITE(*,*) dbid//
     +      ' prepending comment indicator plus space to comment text'
         ctmp(1:2)  = '/ '
         ctmp(3:80) = comm(1:78)
         comm = ctmp
      ENDIF

C --- Test that the last non-blank character in the input record is not
C     already a '/' (if so, blank it out), and determine the starting
C     position in the record for the comment (no earlier than byte 32)..
      j = clen(crec)
      cc = crec(j:j)
      IF (cc.EQ.'/') THEN
         crec(j:j) = ' '
         j = j + 1
      ELSE
         j = j + 2
      ENDIF
      i = MAX(32,j)

C --- Determine the space still remaining in the header record...
      j = 80 - i + 1

C --- Determine the actual length of the keyword comment string...
      k = clen(comm)

C --- Test whether the comment string will fit in the header record...
      IF (k.LE.j) THEN
C        The comment fits within the remaining space in the record...
         crec(i:(i+k-1)) = comm(1:k)
      ELSE
C        There is insufficient space left in the record; test whether to
C        truncate the string (do not start a comment after byte 76)...
         IF (ltrnc.AND.i.LE.76) THEN
            IF (idbg.GT.1) WRITE(*,*)
     +         dbid//' truncating keyword comment to fit within record'
            crec(i:80) = comm(1:(80-i+1))
         ELSE
            IF (idbg.GT.0) WRITE(*,*)
     +         dbid//'insufficient space in record for keyword comment'
            ierr = 2461
            GOTO 9
         ENDIF
      ENDIF


9     IF (idbg.GT.2) WRITE(*,*) dbid//crec(1:clen(crec))
      IF (idbg.GT.1) WRITE(*,*) dbid//
     +   'i=',i,', j=',j,', k=',k,'. On exit, ierr = ',ierr

      RETURN
      END


